@@ -1194,7 +1194,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
             validArguments = False
 
       if self.getOption('cacheHit') or self.getOption('cacheMiss') or self.getOption('cachePublish'):
-         squidPattern = re.compile("[a-z0-9_\-]+/[0-9]+/[a-z0-9]{40}\Z")
+         squidPattern = re.compile(r"[a-z0-9_\-]+/[0-9]+/[a-z0-9]{40}\Z")
          if self.getOption('cacheHit'):
             if not squidPattern.match(self.getOption('cacheHit')):
                errorMessage = "cacheHit pattern is not valid"
@@ -1489,7 +1489,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
                       parameter,
                       separator=""):
       intExpr      = "[0-9]+"
-      numExpr      = "[-+]?(?:[0-9]+\.?[0-9]*|\.[0-9]+)(?:[eEdD][-+]?[0-9]+)?"
+      numExpr      = r"[-+]?(?:[0-9]+\.?[0-9]*|\.[0-9]+)(?:[eEdD][-+]?[0-9]+)?"
       matlabExpr   = "^(%s)[ \t]*:[ \t]*(%s)[ \t]*(?::[ \t]*(%s))?$" % (numExpr,numExpr,numExpr)
       rangeExpr    = "^(%s)[ \t]*-[ \t]*(%s)$" % (numExpr,numExpr)
       rangeByExpr  = "^(%s)[ \t]*[-:][ \t]*(%s)[ \t]+by[ \t]+(%s)$" % (numExpr,numExpr,numExpr)
@@ -1589,7 +1589,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
 
 
    def setSubmitCommandFiles(self):
-      parameterExpr   = "^@@([a-zA-Z0-9_]+) *\= *(.+)"
+      parameterExpr   = r"^@@([a-zA-Z0-9_]+) *\= *(.+)"
       reParameterExpr = re.compile(parameterExpr)
 
       if self.commandOptions.parameters:
@@ -1618,10 +1618,10 @@ submit -p @@file=globnat:indeck* sim.exe @@file
    def setSweepParameters(self):
       exitCode = 0
       if self.commandOptions.parameters:
-         parameterPattern = re.compile('\s*parameter\s+(.*[^\s$])')
-         separatorPattern = re.compile('\s*separator\s+(.*[^\s$])')
-         commentPattern   = re.compile('\s*#.*')
-         parameterExpr    = "^@@([a-zA-Z0-9_]+) *\= *(.+)"
+         parameterPattern = re.compile(r'\s*parameter\s+(.*[^\s$])')
+         separatorPattern = re.compile(r'\s*separator\s+(.*[^\s$])')
+         commentPattern   = re.compile(r'\s*#.*')
+         parameterExpr    = r"^@@([a-zA-Z0-9_]+) *\= *(.+)"
          reParameterExpr = re.compile(parameterExpr)
          for separator,sweepParameters in self.commandOptions.parameters:
             for sweepParameter in sweepParameters.split(';'):
@@ -1681,7 +1681,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
       self.nCSVDataCombinations = 0
       if self.commandOptions.csvData:
          csvDataFile = self.commandOptions.csvData[0]
-         headerExpr   = "^\s*@@([a-zA-Z0-9_]+)\s*$"
+         headerExpr   = r"^\s*@@([a-zA-Z0-9_]+)\s*$"
          reHeaderExpr = re.compile(headerExpr)
          if os.path.isfile(csvDataFile):
             try:
@@ -1914,7 +1914,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
                del parameterCombination[0]
                substitutions = {}
                for parameterName,parameterValue in zip(parameterNames,parameterCombination):
-                  substitutions[parameterName] = parameterValue.replace(' ','\ ')
+                  substitutions[parameterName] = parameterValue.replace(' ',r'\ ')
                yield(substitutions)
          except StopIteration:
             pass
